# coding: utf-8
from spyne.decorator import rpc
from spyne.model.primitive import String

from . import utils
from .types import GetIndexResponse, IndexPeriod


@rpc(
    String, IndexPeriod,
    _in_variable_names=dict(
        report_code='IndexCode', period='IndexPeriod'
    ),
    _returns=GetIndexResponse,
    _out_message_name='GetIndexResponse',
)
def GetIndexRequest(ctx, report_code, period):
    from .. import data
    assert isinstance(period, IndexPeriod)

    data.validate_request(ctx, report_code, period)

    kwargs = dict(
        ctx=ctx, report_code=report_code,
        period_type=period.IndexPeriodType,
    )
    kwargs.update(
        utils.get_report_period(
            period.IndexPeriodType,
            **dict(
                period_date=utils.as_date(period.IndexPeriodDate),
                date_from=utils.as_date(period.IndexPeriodStartDate),
                date_to=utils.as_date(period.IndexPeriodEndDate),
            )
        ),
    )

    out_format = 'xml'
    file_name = '.'.join((report_code, out_format))
    content = data.get_content(**kwargs)

    return GetIndexResponse.create(file_name, content)
